[−][src]Trait heim::host::os::windows::UserExt
Extension for User struct.
Required methods
fn domain(&self) -> &str
Domain name that the user belongs to.
fn address(&self) -> Option<&IpAddr>
Client network address of a RDP session.
At the moment not all possible protocols are supported
(AF_IPX, AF_NETBIOS and AF_UNSPEC families are missing),
and therefore, this method returns Option<&IpAddr>.
It should be expected that method will return &IpAddr directly,
when support for all protocols will arrive.